@@ -6,5 +6,7 @@ from django.urls import re_path
 from core_module_blob_host_app.views.views import BlobHostModule
 
 urlpatterns = [
-    re_path(r'module-blob-host', BlobHostModule.as_view(), name='core_module_blob_host_view'),
+    re_path(
+        r"module-blob-host", BlobHostModule.as_view(), name="core_module_blob_host_view"
+    ),
 ]
